+++
title = "Nested bold and italics"
date = 2017-07-22
tags = ["body"]
draft = false
+++

-   _This is italics, and **this is bold too**, and back to plain
    italics._
-   **This is bold, and _this is italics too_, and back to plain bold.**
